/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.actions;

import com.opensymphony.xwork2.ActionContext;
import com.opensymphony.xwork2.ActionSupport;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.ServletContext;

import org.apache.struts2.StrutsStatics;
import org.wso2.registry.jdbc.JDBCRegistry;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.RegistryException;
import org.wso2.registry.web.ConsoleConstants;
import org.wso2.registry.secure.SecureRegistry;
import org.wso2.usermanager.Realm;

public class SignInAction extends AbstractRegistryAction {

    /**
     * Home path of the user. User will be directed to this path on sign in.
     */
    private String userPath;

    private String userName;
    private String password;

    public String execute() throws Exception {

        ActionContext actionContext = ActionContext.getContext();
        HttpServletRequest request =
                (HttpServletRequest) actionContext.get(StrutsStatics.HTTP_REQUEST);
        ServletContext context = (ServletContext) actionContext.get(StrutsStatics.SERVLET_CONTEXT);
        JDBCRegistry jdbcRegistry = (JDBCRegistry) context.getAttribute(RegistryConstants.REGISTRY);

        Realm realm = (Realm) request.getSession().getServletContext().
                                        getAttribute(RegistryConstants.REGISTRY_REALM);

        try {
            SecureRegistry secureRegistry =
                    new SecureRegistry(userName, password, jdbcRegistry, realm);
            request.getSession().setAttribute(ConsoleConstants.USER_REGISTRY, secureRegistry);

            this.setUserPath(RegistryConstants.ROOT_PATH);

        } catch (RegistryException e) {
            return ActionSupport.ERROR;
        }

        return ActionSupport.SUCCESS;
    }

    public String getNewUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getUserPath() {
        return userPath;
    }

    public void setUserPath(String userPath) {
        this.userPath = userPath;
    }
}
